@@ -260,7 +260,7 @@ class PlainToRichQtReslist : public PlainToRich {
 public:
     virtual string startMatch(unsigned int idx)
     {
-	if (m_hdata) {
+	if (0 && m_hdata) {
 	    string s1, s2;
 	    stringsToString<vector<string> >(m_hdata->groups[idx], s1); 
 	    stringsToString<vector<string> >(m_hdata->ugroups[m_hdata->grpsugidx[idx]], s2);
@@ -407,6 +407,8 @@ void ResList::setDocSource(std::shared_ptr<DocSequence> nsource)
 {
     LOGDEB("ResList::setDocSource()\n");
     m_source = std::shared_ptr<DocSequence>(new DocSource(theconfig, nsource));
+    if (m_pager)
+        m_pager->setDocSource(m_source);
 }
 
 // A query was executed, or the filtering/sorting parameters changed,
